@@ -1,8 +1,13 @@
 class Color():
     def __init__(self):
-        raise NotImplementedError()
+        pass
 
 
 class LinearGradient():
     def __init__(self):
-        raise NotImplementedError()
+        pass
+
+
+class RadialGradient():
+    def __init__(self):
+        pass
